@@ -26,7 +26,7 @@ __all__ = (
     "ListSchemasPaginatorName",
     "ListStatementsPaginatorName",
     "ListTablesPaginatorName",
-    "StatusString",
+    "StatusStringType",
 )
 
 
@@ -36,4 +36,4 @@ ListDatabasesPaginatorName = Literal["list_databases"]
 ListSchemasPaginatorName = Literal["list_schemas"]
 ListStatementsPaginatorName = Literal["list_statements"]
 ListTablesPaginatorName = Literal["list_tables"]
-StatusString = Literal["ABORTED", "ALL", "FAILED", "FINISHED", "PICKED", "STARTED", "SUBMITTED"]
+StatusStringType = Literal["ABORTED", "ALL", "FAILED", "FINISHED", "PICKED", "STARTED", "SUBMITTED"]
